@@ -9,7 +9,7 @@ use Selenium::Remote::WDKeys;
 
 use constant DEBUG => $ENV{MOJO_SELENIUM_DEBUG} || 0;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 my $SCRIPT_NAME = File::Basename::basename($0);
 my $SCREENSHOT  = 1;
@@ -29,15 +29,14 @@ has driver => sub {
 has driver_args          => sub { +{} };
 has screenshot_directory => sub { File::Spec->tmpdir };
 
-has _base => sub {
+has _live_base => sub {
   my $self = shift;
-  my $port = Mojo::IOLoop::Server->generate_port;
-  return Mojo::URL->new("http://127.0.0.1:$port");
+  return Mojo::URL->new($ENV{MOJO_SELENIUM_BASE_URL}) if $ENV{MOJO_SELENIUM_BASE_URL};
+  $self->{live_port} = Mojo::IOLoop::Server->generate_port;
+  return Mojo::URL->new("http://127.0.0.1:$self->{live_port}");
 };
 
-has _live_url => sub { Mojo::URL->new };
-
-has _server => sub {
+has _live_server => sub {
   my $self   = shift;
   my $app    = $self->app or die 'Cannot start server without $t->app(...) set';
   my $server = Mojo::Server::Daemon->new(silent => DEBUG ? 0 : 1);
@@ -50,12 +49,14 @@ has _server => sub {
     }
   );
 
-  $server->app($app)->listen([$self->_base->to_string])
+  $server->app($app)->listen([$self->_live_base->to_string])
     ->start->ioloop->acceptor($server->acceptors->[0]);
 
   return $server;
 };
 
+has _live_url => sub { Mojo::URL->new };
+
 sub active_element_is {
   my ($self, $selector, $desc) = @_;
   my $driver = $self->driver;
@@ -141,23 +142,24 @@ sub live_text_like {
 }
 
 sub navigate_ok {
-  my ($self, $url) = @_;
-  my $err;
+  my $self = shift;
+  my $url  = $self->_live_abs_url(shift);
+  my ($desc, $err);
 
-  $self->_live_url($self->_live_abs_url($url));
-  $self->tx(undef);
-  $self->_server;    # Make sure server is running
-  $self->driver->get($self->_live_url->to_string);
+  $self->tx(undef)->_live_url($url);
+  $self->_live_server if $self->{live_port};    # Make sure server is running
+  $self->driver->get($url->to_string);
 
   if ($self->tx) {
-    $err = $self->tx->error;
+    $desc = "navigate to $url";
+    $err  = $self->tx->error;
     Test::More::diag($err->{message}) if $err and $err->{message};
   }
   else {
-    Test::More::diag('External request? $t->tx() was not set');
+    $desc = "navigate to $url (\$t->tx() is not set)";
   }
 
-  return $self->_test('ok', !$err, _desc("live get $url"));
+  return $self->_test('ok', !$err, _desc($desc));
 }
 
 around new => sub {
@@ -201,7 +203,7 @@ sub _live_abs_url {
   my $url  = Mojo::URL->new(shift);
 
   unless ($url->is_abs) {
-    my $base = $self->_base;
+    my $base = $self->_live_base;
     $url->scheme($base->scheme)->host($base->host)->port($base->port);
   }
 
@@ -299,6 +301,37 @@ provided directly by L<Test::Mojo::Role::Selenium>.
 
 This role is EXPERIMENTAL and subject to change.
 
+=head1 OPTIONAL DEPENDENCIES
+
+L<Selenium::Remote::Driver> require some external dependencies to work. Here
+are a quick intro to install some of the dependencies to make this module work.
+
+=over 2
+
+=item * L<Selenium::Chrome>
+
+  # osx
+  $ brew install chromedriver
+
+  # ubuntu
+  $ sudo apt-get install chromium-chromedriver
+
+  # run tests
+  $ MOJO_SELENIUM_DRIVER=Selenium::Chrome prove -l
+
+=item * L<Selenium::PhantomJS>
+
+  # osx
+  $ brew install phantomjs
+
+  # ubuntu
+  $ sudo apt-get install phantomjs
+
+  # run tests
+  $ MOJO_SELENIUM_DRIVER=Selenium::PhantomJS prove -l
+
+=back
+
 =head1 CAVEAT
 
 L<Test::Mojo/tx> is only populated by this role, if the initial request is done
@@ -306,6 +339,20 @@ by passing a relative path to L</navigate_ok>. This means that methods such as
 L<Test::Mojo/header_is> will not work as expected (probably fail completely) if
 L</navigate_ok> is issued with an absolute path like L<http://mojolicious.org>.
 
+=head1 ENVIRONMENT VARIABLES
+
+=head2 MOJO_SELENIUM_BASE_URL
+
+Setting this variable will make this test send the requests to a remote server,
+instead of starting a local server. Note that this will disable L<Test::Mojo>
+methods such as L</status_is>, since L<Test::Mojo/tx> will not be set. See
+also L</CAVEAT>.
+
+=head2 MOJO_SELENIUM_DRIVER
+
+This variable can be set to a classname, such as L<Selenium::Chrome> or
+L<Selenium::PhantomJS>, which will force the selenium driver.
+
 =head1 ATTRIBUTES
 
 =head2 driver
